# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: zehnder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rzehnder.proto\"\x80\x01\n\x12\x44iscoveryOperation\x12\x33\n\x14searchGatewayRequest\x18\x01 \x01(\x0b\x32\x15.SearchGatewayRequest\x12\x35\n\x15searchGatewayResponse\x18\x02 \x01(\x0b\x32\x16.SearchGatewayResponse\"\x16\n\x14SearchGatewayRequest\"I\n\x15SearchGatewayResponse\x12\x11\n\tipaddress\x18\x01 \x02(\t\x12\x0c\n\x04uuid\x18\x02 \x02(\x0c\x12\x0f\n\x07version\x18\x03 \x02(\r\"\xde\x10\n\x10GatewayOperation\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.GatewayOperation.OperationType\x12/\n\x06result\x18\x02 \x01(\x0e\x32\x1f.GatewayOperation.GatewayResult\x12\x19\n\x11resultDescription\x18\x03 \x01(\t\x12\x11\n\treference\x18\x04 \x01(\r\"\x95\x0e\n\rOperationType\x12\x0f\n\x0bNoOperation\x10\x00\x12\x19\n\x15SetAddressRequestType\x10\x01\x12\x1a\n\x16RegisterAppRequestType\x10\x02\x12\x1b\n\x17StartSessionRequestType\x10\x03\x12\x1b\n\x17\x43loseSessionRequestType\x10\x04\x12!\n\x1dListRegisteredAppsRequestType\x10\x05\x12\x1c\n\x18\x44\x65registerAppRequestType\x10\x06\x12\x18\n\x14\x43hangePinRequestType\x10\x07\x12 \n\x1cGetRemoteAccessIdRequestType\x10\x08\x12 \n\x1cSetRemoteAccessIdRequestType\x10\t\x12\x1b\n\x17GetSupportIdRequestType\x10\n\x12\x1b\n\x17SetSupportIdRequestType\x10\x0b\x12\x17\n\x13GetWebIdRequestType\x10\x0c\x12\x17\n\x13SetWebIdRequestType\x10\r\x12\x18\n\x14SetPushIdRequestType\x10\x0e\x12\x14\n\x10\x44\x65\x62ugRequestType\x10\x0f\x12\x16\n\x12UpgradeRequestType\x10\x10\x12 \n\x1cSetDeviceSettingsRequestType\x10\x11\x12\x16\n\x12VersionRequestType\x10\x12\x12\x19\n\x15SetAddressConfirmType\x10\x33\x12\x1a\n\x16RegisterAppConfirmType\x10\x34\x12\x1b\n\x17StartSessionConfirmType\x10\x35\x12\x1b\n\x17\x43loseSessionConfirmType\x10\x36\x12!\n\x1dListRegisteredAppsConfirmType\x10\x37\x12\x1c\n\x18\x44\x65registerAppConfirmType\x10\x38\x12\x18\n\x14\x43hangePinConfirmType\x10\x39\x12 \n\x1cGetRemoteAccessIdConfirmType\x10:\x12 \n\x1cSetRemoteAccessIdConfirmType\x10;\x12\x1b\n\x17GetSupportIdConfirmType\x10<\x12\x1b\n\x17SetSupportIdConfirmType\x10=\x12\x17\n\x13GetWebIdConfirmType\x10>\x12\x17\n\x13SetWebIdConfirmType\x10?\x12\x18\n\x14SetPushIdConfirmType\x10@\x12\x14\n\x10\x44\x65\x62ugConfirmType\x10\x41\x12\x16\n\x12UpgradeConfirmType\x10\x42\x12 \n\x1cSetDeviceSettingsConfirmType\x10\x43\x12\x16\n\x12VersionConfirmType\x10\x44\x12\x1b\n\x17GatewayNotificationType\x10\x64\x12\x11\n\rKeepAliveType\x10\x65\x12\x14\n\x10\x46\x61\x63toryResetType\x10\x66\x12\x15\n\x11\x43nTimeRequestType\x10\x1e\x12\x15\n\x11\x43nTimeConfirmType\x10\x1f\x12\x15\n\x11\x43nNodeRequestType\x10*\x12\x1a\n\x16\x43nNodeNotificationType\x10 \x12\x14\n\x10\x43nRmiRequestType\x10!\x12\x15\n\x11\x43nRmiResponseType\x10\"\x12\x19\n\x15\x43nRmiAsyncRequestType\x10#\x12\x19\n\x15\x43nRmiAsyncConfirmType\x10$\x12\x1a\n\x16\x43nRmiAsyncResponseType\x10%\x12\x15\n\x11\x43nRpdoRequestType\x10&\x12\x15\n\x11\x43nRpdoConfirmType\x10\'\x12\x1a\n\x16\x43nRpdoNotificationType\x10(\x12\x1b\n\x17\x43nAlarmNotificationType\x10)\x12 \n\x1c\x43nFupReadRegisterRequestType\x10\x46\x12 \n\x1c\x43nFupReadRegisterConfirmType\x10G\x12 \n\x1c\x43nFupProgramBeginRequestType\x10H\x12 \n\x1c\x43nFupProgramBeginConfirmType\x10I\x12\x1b\n\x17\x43nFupProgramRequestType\x10J\x12\x1b\n\x17\x43nFupProgramConfirmType\x10K\x12\x1e\n\x1a\x43nFupProgramEndRequestType\x10L\x12\x1e\n\x1a\x43nFupProgramEndConfirmType\x10M\x12\x18\n\x14\x43nFupReadRequestType\x10N\x12\x18\n\x14\x43nFupReadConfirmType\x10O\x12\x19\n\x15\x43nFupResetRequestType\x10P\x12\x19\n\x15\x43nFupResetConfirmType\x10Q\"\xa3\x01\n\rGatewayResult\x12\x06\n\x02OK\x10\x00\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x11\n\rNOT_REACHABLE\x10\x03\x12\x11\n\rOTHER_SESSION\x10\x04\x12\x0f\n\x0bNOT_ALLOWED\x10\x05\x12\x10\n\x0cNO_RESOURCES\x10\x06\x12\r\n\tNOT_EXIST\x10\x07\x12\r\n\tRMI_ERROR\x10\x08\"M\n\x13GatewayNotification\x12\x11\n\tpushUUIDs\x18\x01 \x03(\x0c\x12#\n\x05\x61larm\x18\x02 \x01(\x0b\x32\x14.CnAlarmNotification\"\x0b\n\tKeepAlive\" \n\x0c\x46\x61\x63toryReset\x12\x10\n\x08resetKey\x18\x01 \x02(\x0c\"D\n\x18SetDeviceSettingsRequest\x12\x12\n\nmacAddress\x18\x01 \x02(\x0c\x12\x14\n\x0cserialNumber\x18\x02 \x02(\t\"\x1a\n\x18SetDeviceSettingsConfirm\"!\n\x11SetAddressRequest\x12\x0c\n\x04uuid\x18\x01 \x02(\x0c\"\x13\n\x11SetAddressConfirm\"C\n\x12RegisterAppRequest\x12\x0c\n\x04uuid\x18\x01 \x02(\x0c\x12\x0b\n\x03pin\x18\x02 \x02(\r\x12\x12\n\ndevicename\x18\x03 \x02(\t\"\x14\n\x12RegisterAppConfirm\"\'\n\x13StartSessionRequest\x12\x10\n\x08takeover\x18\x01 \x01(\x08\":\n\x13StartSessionConfirm\x12\x12\n\ndevicename\x18\x01 \x01(\t\x12\x0f\n\x07resumed\x18\x02 \x01(\x08\"\x15\n\x13\x43loseSessionRequest\"\x15\n\x13\x43loseSessionConfirm\"\x1b\n\x19ListRegisteredAppsRequest\"r\n\x19ListRegisteredAppsConfirm\x12,\n\x04\x61pps\x18\x01 \x03(\x0b\x32\x1e.ListRegisteredAppsConfirm.App\x1a\'\n\x03\x41pp\x12\x0c\n\x04uuid\x18\x01 \x02(\x0c\x12\x12\n\ndevicename\x18\x02 \x02(\t\"$\n\x14\x44\x65registerAppRequest\x12\x0c\n\x04uuid\x18\x01 \x02(\x0c\"\x16\n\x14\x44\x65registerAppConfirm\"2\n\x10\x43hangePinRequest\x12\x0e\n\x06oldpin\x18\x01 \x02(\r\x12\x0e\n\x06newpin\x18\x02 \x02(\r\"\x12\n\x10\x43hangePinConfirm\"\x1a\n\x18GetRemoteAccessIdRequest\"(\n\x18GetRemoteAccessIdConfirm\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\"(\n\x18SetRemoteAccessIdRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\"\x1a\n\x18SetRemoteAccessIdConfirm\"\x15\n\x13GetSupportIdRequest\":\n\x13GetSupportIdConfirm\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x15\n\rremainingTime\x18\x02 \x01(\r\"6\n\x13SetSupportIdRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\x12\x11\n\tvalidTime\x18\x02 \x01(\r\"\x15\n\x13SetSupportIdConfirm\"\x11\n\x0fGetWebIdRequest\"\x1f\n\x0fGetWebIdConfirm\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\"\x1f\n\x0fSetWebIdRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\"\x11\n\x0fSetWebIdConfirm\" \n\x10SetPushIdRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\x0c\"\x12\n\x10SetPushIdConfirm\"\xc0\x01\n\x0eUpgradeRequest\x12\x36\n\x07\x63ommand\x18\x01 \x01(\x0e\x32%.UpgradeRequest.UpgradeRequestCommand\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\"g\n\x15UpgradeRequestCommand\x12\x11\n\rUPGRADE_START\x10\x00\x12\x14\n\x10UPGRADE_CONTINUE\x10\x01\x12\x12\n\x0eUPGRADE_FINISH\x10\x02\x12\x11\n\rUPGRADE_ABORT\x10\x03\"\x10\n\x0eUpgradeConfirm\"\xba\x03\n\x0c\x44\x65\x62ugRequest\x12\x32\n\x07\x63ommand\x18\x01 \x02(\x0e\x32!.DebugRequest.DebugRequestCommand\x12\x10\n\x08\x61rgument\x18\x02 \x01(\x05\"\xe3\x02\n\x13\x44\x65\x62ugRequestCommand\x12\x0c\n\x08\x44\x42G_ECHO\x10\x00\x12\r\n\tDBG_SLEEP\x10\x01\x12\x14\n\x10\x44\x42G_SESSION_ECHO\x10\x02\x12\x16\n\x12\x44\x42G_PRINT_SETTINGS\x10\x03\x12\r\n\tDBG_ALARM\x10\x04\x12\x0b\n\x07\x44\x42G_LED\x10\x05\x12\x0b\n\x07\x44\x42G_GPI\x10\x06\x12\x0b\n\x07\x44\x42G_GPO\x10\x07\x12\x13\n\x0f\x44\x42G_RS232_WRITE\x10\x08\x12\x12\n\x0e\x44\x42G_RS232_READ\x10\t\x12\x11\n\rDBG_CAN_WRITE\x10\n\x12\x10\n\x0c\x44\x42G_CAN_READ\x10\x0b\x12\x11\n\rDBG_KNX_WRITE\x10\x0c\x12\x10\n\x0c\x44\x42G_KNX_READ\x10\r\x12\x0e\n\nDBG_TOGGLE\x10\x0e\x12\x0e\n\nDBG_REBOOT\x10\x0f\x12\r\n\tDBG_CLOUD\x10\x10\x12\x13\n\x0f\x44\x42G_EEPROM_READ\x10\x11\x12\x14\n\x10\x44\x42G_EEPROM_WRITE\x10\x12\"\x1e\n\x0c\x44\x65\x62ugConfirm\x12\x0e\n\x06result\x18\x01 \x02(\x05\"\x10\n\x0eVersionRequest\"W\n\x0eVersionConfirm\x12\x16\n\x0egatewayVersion\x18\x01 \x02(\r\x12\x14\n\x0cserialNumber\x18\x02 \x02(\t\x12\x17\n\x0f\x63omfoNetVersion\x18\x03 \x02(\r\" \n\rCnTimeRequest\x12\x0f\n\x07setTime\x18\x01 \x01(\r\"$\n\rCnTimeConfirm\x12\x13\n\x0b\x63urrentTime\x18\x01 \x02(\r\"\x0f\n\rCnNodeRequest\"\xcf\x01\n\x12\x43nNodeNotification\x12\x0e\n\x06nodeId\x18\x01 \x02(\r\x12\x14\n\tproductId\x18\x02 \x01(\r:\x01\x30\x12\x0e\n\x06zoneId\x18\x03 \x01(\r\x12.\n\x04mode\x18\x04 \x01(\x0e\x32 .CnNodeNotification.NodeModeType\"S\n\x0cNodeModeType\x12\x0f\n\x0bNODE_LEGACY\x10\x00\x12\x10\n\x0cNODE_OFFLINE\x10\x01\x12\x0f\n\x0bNODE_NORMAL\x10\x02\x12\x0f\n\x0bNODE_UPDATE\x10\x03\"/\n\x0c\x43nRmiRequest\x12\x0e\n\x06nodeId\x18\x01 \x02(\r\x12\x0f\n\x07message\x18\x02 \x02(\x0c\"3\n\rCnRmiResponse\x12\x11\n\x06result\x18\x01 \x01(\r:\x01\x30\x12\x0f\n\x07message\x18\x02 \x01(\x0c\"4\n\x11\x43nRmiAsyncRequest\x12\x0e\n\x06nodeId\x18\x01 \x02(\r\x12\x0f\n\x07message\x18\x02 \x02(\x0c\"&\n\x11\x43nRmiAsyncConfirm\x12\x11\n\x06result\x18\x01 \x01(\r:\x01\x30\"8\n\x12\x43nRmiAsyncResponse\x12\x11\n\x06result\x18\x01 \x01(\r:\x01\x30\x12\x0f\n\x07message\x18\x02 \x01(\x0c\"[\n\rCnRpdoRequest\x12\x0c\n\x04pdid\x18\x01 \x02(\r\x12\x11\n\x04zone\x18\x02 \x01(\r:\x03\x32\x35\x35\x12\x0c\n\x04type\x18\x03 \x01(\r\x12\x1b\n\x07timeout\x18\x04 \x01(\r:\n4294967295\"\x0f\n\rCnRpdoConfirm\"0\n\x12\x43nRpdoNotification\x12\x0c\n\x04pdid\x18\x01 \x02(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x02(\x0c\"\xaf\x01\n\x13\x43nAlarmNotification\x12\x0c\n\x04zone\x18\x01 \x01(\r\x12\x11\n\tproductId\x18\x02 \x01(\r\x12\x16\n\x0eproductVariant\x18\x03 \x01(\r\x12\x14\n\x0cserialNumber\x18\x04 \x01(\t\x12\x18\n\x10swProgramVersion\x18\x05 \x01(\r\x12\x0e\n\x06\x65rrors\x18\x06 \x01(\x0c\x12\x0f\n\x07\x65rrorId\x18\x07 \x01(\r\x12\x0e\n\x06nodeId\x18\x08 \x01(\r\"K\n\x18\x43nFupReadRegisterRequest\x12\x0c\n\x04node\x18\x01 \x02(\r\x12\x12\n\nregisterId\x18\x02 \x02(\r\x12\r\n\x05index\x18\x03 \x01(\r\")\n\x18\x43nFupReadRegisterConfirm\x12\r\n\x05value\x18\x01 \x02(\r\":\n\x18\x43nFupProgramBeginRequest\x12\x0c\n\x04node\x18\x01 \x03(\r\x12\x10\n\x05\x62lock\x18\x02 \x01(\r:\x01\x30\"\x1a\n\x18\x43nFupProgramBeginConfirm\"$\n\x13\x43nFupProgramRequest\x12\r\n\x05\x63hunk\x18\x01 \x02(\x0c\"\x15\n\x13\x43nFupProgramConfirm\"\x18\n\x16\x43nFupProgramEndRequest\"\x18\n\x16\x43nFupProgramEndConfirm\"2\n\x10\x43nFupReadRequest\x12\x0c\n\x04node\x18\x01 \x02(\r\x12\x10\n\x05\x62lock\x18\x02 \x01(\r:\x01\x30\"6\n\x10\x43nFupReadConfirm\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\x12\x13\n\x04last\x18\x02 \x01(\x08:\x05\x66\x61lse\"!\n\x11\x43nFupResetRequest\x12\x0c\n\x04node\x18\x01 \x02(\r\"\x13\n\x11\x43nFupResetConfirm')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zehnder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DISCOVERYOPERATION._serialized_start=18
  _DISCOVERYOPERATION._serialized_end=146
  _SEARCHGATEWAYREQUEST._serialized_start=148
  _SEARCHGATEWAYREQUEST._serialized_end=170
  _SEARCHGATEWAYRESPONSE._serialized_start=172
  _SEARCHGATEWAYRESPONSE._serialized_end=245
  _GATEWAYOPERATION._serialized_start=248
  _GATEWAYOPERATION._serialized_end=2390
  _GATEWAYOPERATION_OPERATIONTYPE._serialized_start=411
  _GATEWAYOPERATION_OPERATIONTYPE._serialized_end=2224
  _GATEWAYOPERATION_GATEWAYRESULT._serialized_start=2227
  _GATEWAYOPERATION_GATEWAYRESULT._serialized_end=2390
  _GATEWAYNOTIFICATION._serialized_start=2392
  _GATEWAYNOTIFICATION._serialized_end=2469
  _KEEPALIVE._serialized_start=2471
  _KEEPALIVE._serialized_end=2482
  _FACTORYRESET._serialized_start=2484
  _FACTORYRESET._serialized_end=2516
  _SETDEVICESETTINGSREQUEST._serialized_start=2518
  _SETDEVICESETTINGSREQUEST._serialized_end=2586
  _SETDEVICESETTINGSCONFIRM._serialized_start=2588
  _SETDEVICESETTINGSCONFIRM._serialized_end=2614
  _SETADDRESSREQUEST._serialized_start=2616
  _SETADDRESSREQUEST._serialized_end=2649
  _SETADDRESSCONFIRM._serialized_start=2651
  _SETADDRESSCONFIRM._serialized_end=2670
  _REGISTERAPPREQUEST._serialized_start=2672
  _REGISTERAPPREQUEST._serialized_end=2739
  _REGISTERAPPCONFIRM._serialized_start=2741
  _REGISTERAPPCONFIRM._serialized_end=2761
  _STARTSESSIONREQUEST._serialized_start=2763
  _STARTSESSIONREQUEST._serialized_end=2802
  _STARTSESSIONCONFIRM._serialized_start=2804
  _STARTSESSIONCONFIRM._serialized_end=2862
  _CLOSESESSIONREQUEST._serialized_start=2864
  _CLOSESESSIONREQUEST._serialized_end=2885
  _CLOSESESSIONCONFIRM._serialized_start=2887
  _CLOSESESSIONCONFIRM._serialized_end=2908
  _LISTREGISTEREDAPPSREQUEST._serialized_start=2910
  _LISTREGISTEREDAPPSREQUEST._serialized_end=2937
  _LISTREGISTEREDAPPSCONFIRM._serialized_start=2939
  _LISTREGISTEREDAPPSCONFIRM._serialized_end=3053
  _LISTREGISTEREDAPPSCONFIRM_APP._serialized_start=3014
  _LISTREGISTEREDAPPSCONFIRM_APP._serialized_end=3053
  _DEREGISTERAPPREQUEST._serialized_start=3055
  _DEREGISTERAPPREQUEST._serialized_end=3091
  _DEREGISTERAPPCONFIRM._serialized_start=3093
  _DEREGISTERAPPCONFIRM._serialized_end=3115
  _CHANGEPINREQUEST._serialized_start=3117
  _CHANGEPINREQUEST._serialized_end=3167
  _CHANGEPINCONFIRM._serialized_start=3169
  _CHANGEPINCONFIRM._serialized_end=3187
  _GETREMOTEACCESSIDREQUEST._serialized_start=3189
  _GETREMOTEACCESSIDREQUEST._serialized_end=3215
  _GETREMOTEACCESSIDCONFIRM._serialized_start=3217
  _GETREMOTEACCESSIDCONFIRM._serialized_end=3257
  _SETREMOTEACCESSIDREQUEST._serialized_start=3259
  _SETREMOTEACCESSIDREQUEST._serialized_end=3299
  _SETREMOTEACCESSIDCONFIRM._serialized_start=3301
  _SETREMOTEACCESSIDCONFIRM._serialized_end=3327
  _GETSUPPORTIDREQUEST._serialized_start=3329
  _GETSUPPORTIDREQUEST._serialized_end=3350
  _GETSUPPORTIDCONFIRM._serialized_start=3352
  _GETSUPPORTIDCONFIRM._serialized_end=3410
  _SETSUPPORTIDREQUEST._serialized_start=3412
  _SETSUPPORTIDREQUEST._serialized_end=3466
  _SETSUPPORTIDCONFIRM._serialized_start=3468
  _SETSUPPORTIDCONFIRM._serialized_end=3489
  _GETWEBIDREQUEST._serialized_start=3491
  _GETWEBIDREQUEST._serialized_end=3508
  _GETWEBIDCONFIRM._serialized_start=3510
  _GETWEBIDCONFIRM._serialized_end=3541
  _SETWEBIDREQUEST._serialized_start=3543
  _SETWEBIDREQUEST._serialized_end=3574
  _SETWEBIDCONFIRM._serialized_start=3576
  _SETWEBIDCONFIRM._serialized_end=3593
  _SETPUSHIDREQUEST._serialized_start=3595
  _SETPUSHIDREQUEST._serialized_end=3627
  _SETPUSHIDCONFIRM._serialized_start=3629
  _SETPUSHIDCONFIRM._serialized_end=3647
  _UPGRADEREQUEST._serialized_start=3650
  _UPGRADEREQUEST._serialized_end=3842
  _UPGRADEREQUEST_UPGRADEREQUESTCOMMAND._serialized_start=3739
  _UPGRADEREQUEST_UPGRADEREQUESTCOMMAND._serialized_end=3842
  _UPGRADECONFIRM._serialized_start=3844
  _UPGRADECONFIRM._serialized_end=3860
  _DEBUGREQUEST._serialized_start=3863
  _DEBUGREQUEST._serialized_end=4305
  _DEBUGREQUEST_DEBUGREQUESTCOMMAND._serialized_start=3950
  _DEBUGREQUEST_DEBUGREQUESTCOMMAND._serialized_end=4305
  _DEBUGCONFIRM._serialized_start=4307
  _DEBUGCONFIRM._serialized_end=4337
  _VERSIONREQUEST._serialized_start=4339
  _VERSIONREQUEST._serialized_end=4355
  _VERSIONCONFIRM._serialized_start=4357
  _VERSIONCONFIRM._serialized_end=4444
  _CNTIMEREQUEST._serialized_start=4446
  _CNTIMEREQUEST._serialized_end=4478
  _CNTIMECONFIRM._serialized_start=4480
  _CNTIMECONFIRM._serialized_end=4516
  _CNNODEREQUEST._serialized_start=4518
  _CNNODEREQUEST._serialized_end=4533
  _CNNODENOTIFICATION._serialized_start=4536
  _CNNODENOTIFICATION._serialized_end=4743
  _CNNODENOTIFICATION_NODEMODETYPE._serialized_start=4660
  _CNNODENOTIFICATION_NODEMODETYPE._serialized_end=4743
  _CNRMIREQUEST._serialized_start=4745
  _CNRMIREQUEST._serialized_end=4792
  _CNRMIRESPONSE._serialized_start=4794
  _CNRMIRESPONSE._serialized_end=4845
  _CNRMIASYNCREQUEST._serialized_start=4847
  _CNRMIASYNCREQUEST._serialized_end=4899
  _CNRMIASYNCCONFIRM._serialized_start=4901
  _CNRMIASYNCCONFIRM._serialized_end=4939
  _CNRMIASYNCRESPONSE._serialized_start=4941
  _CNRMIASYNCRESPONSE._serialized_end=4997
  _CNRPDOREQUEST._serialized_start=4999
  _CNRPDOREQUEST._serialized_end=5090
  _CNRPDOCONFIRM._serialized_start=5092
  _CNRPDOCONFIRM._serialized_end=5107
  _CNRPDONOTIFICATION._serialized_start=5109
  _CNRPDONOTIFICATION._serialized_end=5157
  _CNALARMNOTIFICATION._serialized_start=5160
  _CNALARMNOTIFICATION._serialized_end=5335
  _CNFUPREADREGISTERREQUEST._serialized_start=5337
  _CNFUPREADREGISTERREQUEST._serialized_end=5412
  _CNFUPREADREGISTERCONFIRM._serialized_start=5414
  _CNFUPREADREGISTERCONFIRM._serialized_end=5455
  _CNFUPPROGRAMBEGINREQUEST._serialized_start=5457
  _CNFUPPROGRAMBEGINREQUEST._serialized_end=5515
  _CNFUPPROGRAMBEGINCONFIRM._serialized_start=5517
  _CNFUPPROGRAMBEGINCONFIRM._serialized_end=5543
  _CNFUPPROGRAMREQUEST._serialized_start=5545
  _CNFUPPROGRAMREQUEST._serialized_end=5581
  _CNFUPPROGRAMCONFIRM._serialized_start=5583
  _CNFUPPROGRAMCONFIRM._serialized_end=5604
  _CNFUPPROGRAMENDREQUEST._serialized_start=5606
  _CNFUPPROGRAMENDREQUEST._serialized_end=5630
  _CNFUPPROGRAMENDCONFIRM._serialized_start=5632
  _CNFUPPROGRAMENDCONFIRM._serialized_end=5656
  _CNFUPREADREQUEST._serialized_start=5658
  _CNFUPREADREQUEST._serialized_end=5708
  _CNFUPREADCONFIRM._serialized_start=5710
  _CNFUPREADCONFIRM._serialized_end=5764
  _CNFUPRESETREQUEST._serialized_start=5766
  _CNFUPRESETREQUEST._serialized_end=5799
  _CNFUPRESETCONFIRM._serialized_start=5801
  _CNFUPRESETCONFIRM._serialized_end=5820
# @@protoc_insertion_point(module_scope)
